@@ -2,7 +2,7 @@ package Dist::Zilla::PluginBundle::Author::DOMM;
 
 # ABSTRACT: Dist::Zilla config suiting my needs
 
-our $VERSION = '0.909'; # VERSION
+our $VERSION = '0.910'; # VERSION
 
 use Moose;
 use namespace::autoclean;
@@ -36,6 +36,7 @@ use Dist::Zilla::Plugin::TestRelease;
 use Dist::Zilla::Plugin::ReadmeAnyFromPod;
 use Dist::Zilla::Plugin::CopyFilesFromBuild;
 use Dist::Zilla::Plugin::GithubMeta;
+use Dist::Zilla::Plugin::SourceHutMeta;
 use Dist::Zilla::Plugin::Git::Check;
 use Dist::Zilla::Plugin::ConfirmRelease;
 use Dist::Zilla::Plugin::UploadToCPAN;
@@ -51,13 +52,18 @@ has homepage => (
   lazy    => 1 ,
   default => sub { $_[0]->payload->{homepage} } ,
 );
+has issues => (
+  is      => 'ro' ,
+  isa     => 'Bool' ,
+  lazy    => 0,
+);
 
 sub configure {
     my $self = shift;
 
     $self->add_plugins(
         [ 'Git::GatherDir' =>
-            { exclude_filename => [qw/README.pod META.json cpanfile/] }],
+            { exclude_filename => [qw/README.pod META.json cpanfile LICENSE/] }],
         'PruneCruft',
         'ManifestSkip',
         'License',
@@ -81,7 +87,8 @@ sub configure {
         'PodWeaver',
         'InstallGuide',
         ['Test::Compile' => {
-            fake_home => 1
+            fake_home => 1,
+            fail_on_warning=>'none',
         }],
         'TestRelease',
         [ 'ReadmeAnyFromPod' => { # TODO escaping of '::' in metacpan urls in readme
@@ -89,12 +96,16 @@ sub configure {
             filename=>'README.md',
             location=>'build',
         }],
-        [ 'CopyFilesFromBuild' => { copy => ['README.md', 'cpanfile'] } ],
+        [ 'CopyFilesFromBuild' => { copy => ['README.md', 'cpanfile', 'LICENSE'] } ],
         # TODO default homepage should be metacpan!
         ['GithubMeta' => {
             issues=>1,
             ($self->homepage ? (homepage => $self->homepage) : ()),
         }],
+        ['SourceHutMeta' => {
+            issues => $self->issues,
+            ($self->homepage ? (homepage => $self->homepage) : ()),
+        }],
         [ 'Git::Check' => {
             allow_dirty => [qw/dist.ini Changes README.md cpanfile/]
         }],
@@ -131,7 +142,7 @@ Dist::Zilla::PluginBundle::Author::DOMM - Dist::Zilla config suiting my needs
 
 =head1 VERSION
 
-version 0.909
+version 0.910
 
 =head1 DESCRIPTION
 
